pub async fn post_subscription(
__arg0: State<App>,
__arg1: Auth,
__arg2: Json<CreateSubscriptionRequest>,
) -> Result<Json<SubscriptionResponse>, (StatusCode, String)>Expand description
POST /api/notification/subscription
Registers a push notification subscription for the authenticated user. The subscription will be stored and used to send push notifications when the user is offline.